move_across_filesystems

Function move_across_filesystems 

pub fn move_across_filesystems<'a>(
    source: &'a (impl FileSystem + ?Sized),
    destination: &'a (impl FileSystem + ?Sized),
    from: &'a Path,
    to: &'a Path,
) -> BoxFuture<'a, Result<()>>
Move a file across filesystem boundaries by copying it into the destination and then removing the original.